@@ -63,7 +63,7 @@ use version 0.77;
 use warnings;
 
 # ABSTRACT: Test your Dist::Zilla plugin
-our $VERSION = 'v0.4.3_02'; # TRIAL VERSION
+our $VERSION = 'v0.4.3_03'; # TRIAL VERSION
 
 use Dist::Zilla::Tester::DieHard v0.6.0;    # `Survivor` should have `tempdir_obj` attribute.
 use File::Temp qw{ tempdir };
@@ -545,15 +545,29 @@ after run_test => sub {
         $self->{ _annotation } = '';
     };
     # Manage temporary directory:
-    if ( my $tempdir = $self->tzil->tempdir_obj ) {
-        # `tzil` could be `Survivor` which does not have temp dir (`tempdir_obj` returns `undef`).
-        my $cleanup = $Cleanup;
-        if ( $cleanup == 1 ) {
-            $cleanup = $tb->is_passing;
-        };
-        if ( not $cleanup ) {
-            diag( "tempdir: $tempdir" );
-            $tempdir->unlink_on_destroy( $cleanup );
+    if ( $Cleanup < 2 ) {
+        if ( $self->tzil->can( 'tempdir_obj' ) ) {
+            if ( my $tempdir = $self->tzil->tempdir_obj ) {
+                # `tzil` could be `Survivor` which does not have temp dir (`tempdir_obj` returns
+                # `undef`).
+                my $cleanup = $Cleanup;
+                if ( $cleanup == 1 ) {
+                    $cleanup = $tb->is_passing;
+                };
+                if ( not $cleanup ) {
+                    diag( "tempdir: $tempdir" );
+                    $tempdir->unlink_on_destroy( $cleanup );
+                };
+            };
+        } else {
+            require Dist::Zilla;
+            diag(
+                "You are running Dist::Zilla $Dist::Zilla::VERSION. Temporary directory will be " .
+                "unconditionally cleaned up, because Test::Zilla::Tester::_Builder does not have " .
+                "tempdir_obj attribute. " .
+                "(tempdir_obj attribute appeared in Dist::Zilla::Tester::_Builder 5.021.)"
+            );
+            $Cleanup = 2;   # Avoid printing the message again and again.
         };
     };
 };
@@ -629,7 +643,7 @@ Test::Dist::Zilla - Test your Dist::Zilla plugin
 
 =head1 VERSION
 
-Version v0.4.3_02, released on 2016-12-20 20:49 UTC.
+Version v0.4.3_03, released on 2016-12-23 20:12 UTC.
 This is a B<trial release>.
 
 =head1 SYNOPSIS
